# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import enum

import winrt.system
from winrt import _winrt_windows_devices_midi

__all__ = [
    "MidiMessageType",
    "MidiActiveSensingMessage",
    "MidiChannelPressureMessage",
    "MidiContinueMessage",
    "MidiControlChangeMessage",
    "MidiInPort",
    "MidiMessageReceivedEventArgs",
    "MidiNoteOffMessage",
    "MidiNoteOnMessage",
    "MidiOutPort",
    "MidiPitchBendChangeMessage",
    "MidiPolyphonicKeyPressureMessage",
    "MidiProgramChangeMessage",
    "MidiSongPositionPointerMessage",
    "MidiSongSelectMessage",
    "MidiStartMessage",
    "MidiStopMessage",
    "MidiSynthesizer",
    "MidiSystemExclusiveMessage",
    "MidiSystemResetMessage",
    "MidiTimeCodeMessage",
    "MidiTimingClockMessage",
    "MidiTuneRequestMessage",
    "IMidiMessage",
    "IMidiOutPort",
]

class MidiMessageType(enum.IntEnum):
    NONE = 0
    NOTE_OFF = 128
    NOTE_ON = 144
    POLYPHONIC_KEY_PRESSURE = 160
    CONTROL_CHANGE = 176
    PROGRAM_CHANGE = 192
    CHANNEL_PRESSURE = 208
    PITCH_BEND_CHANGE = 224
    SYSTEM_EXCLUSIVE = 240
    MIDI_TIME_CODE = 241
    SONG_POSITION_POINTER = 242
    SONG_SELECT = 243
    TUNE_REQUEST = 246
    END_SYSTEM_EXCLUSIVE = 247
    TIMING_CLOCK = 248
    START = 250
    CONTINUE = 251
    STOP = 252
    ACTIVE_SENSING = 254
    SYSTEM_RESET = 255

MidiActiveSensingMessage = _winrt_windows_devices_midi.MidiActiveSensingMessage
MidiChannelPressureMessage = _winrt_windows_devices_midi.MidiChannelPressureMessage
MidiContinueMessage = _winrt_windows_devices_midi.MidiContinueMessage
MidiControlChangeMessage = _winrt_windows_devices_midi.MidiControlChangeMessage
MidiInPort = _winrt_windows_devices_midi.MidiInPort
MidiMessageReceivedEventArgs = _winrt_windows_devices_midi.MidiMessageReceivedEventArgs
MidiNoteOffMessage = _winrt_windows_devices_midi.MidiNoteOffMessage
MidiNoteOnMessage = _winrt_windows_devices_midi.MidiNoteOnMessage
MidiOutPort = _winrt_windows_devices_midi.MidiOutPort
MidiPitchBendChangeMessage = _winrt_windows_devices_midi.MidiPitchBendChangeMessage
MidiPolyphonicKeyPressureMessage = _winrt_windows_devices_midi.MidiPolyphonicKeyPressureMessage
MidiProgramChangeMessage = _winrt_windows_devices_midi.MidiProgramChangeMessage
MidiSongPositionPointerMessage = _winrt_windows_devices_midi.MidiSongPositionPointerMessage
MidiSongSelectMessage = _winrt_windows_devices_midi.MidiSongSelectMessage
MidiStartMessage = _winrt_windows_devices_midi.MidiStartMessage
MidiStopMessage = _winrt_windows_devices_midi.MidiStopMessage
MidiSynthesizer = _winrt_windows_devices_midi.MidiSynthesizer
MidiSystemExclusiveMessage = _winrt_windows_devices_midi.MidiSystemExclusiveMessage
MidiSystemResetMessage = _winrt_windows_devices_midi.MidiSystemResetMessage
MidiTimeCodeMessage = _winrt_windows_devices_midi.MidiTimeCodeMessage
MidiTimingClockMessage = _winrt_windows_devices_midi.MidiTimingClockMessage
MidiTuneRequestMessage = _winrt_windows_devices_midi.MidiTuneRequestMessage
IMidiMessage = _winrt_windows_devices_midi.IMidiMessage
IMidiOutPort = _winrt_windows_devices_midi.IMidiOutPort
